<template>
  <div class="mod-config">
    <basic-container>
      <ttable
        :table="table"
        @handleSelectionChange="handleSelectionChange"
        :uploadInfo="uploadInfo"
        :isShowHide="true"
        :prelang="prelang"
        :options="options"
        :bottomOffset="125"
        :ajaxFun="ajaxFun"
        ref="certificateTable"
      >
        <template #toolbar></template>
      </ttable>
      <!-- 弹窗, 新增 / 修改 -->
      <table-form
        v-if="addOrUpdateVisible"
        ref="addOrUpdate"
        @refreshDataList="getData"
      ></table-form>
    </basic-container>
    <secretFormDialog
      :currshowlist.sync="showSecretForm"
      :formPageType="formPageType"
      @goOnListPrint="goOnListPrint"
    />
  </div>
</template>

<script>
import {
  fetchListFeederCertificate,
  delFeederCertificate,
  updatePrintNum
} from '@/api/certificate/feedercertificate'
import TableForm from './certificate-form'
import { mapGetters } from 'vuex'
import ttable from '@/views/common/ztt-table.vue'
import { remote } from '../../../api/admin/dict'
import getLodop from '@/util/lodop'
import { getYearAndMonth } from '@/util/date'
import { judgeLabelMark } from '@/api/warehouse/check'
import secretFormDialog from './secret-form.vue'

export default {
  data() {
    return {
      formPageType: '2',
      showSecretForm: false,
      ajaxFun: fetchListFeederCertificate,
      addOrUpdateVisible: false,
      multipleSelection: [],
      uploadInfo: {
        // 是否展示上传EXCEL以及对应的url
        isShow: false,
        url: ''
      },
      prelang: 'certificate',
      options: {
        height: 300, // 默认高度-为了表头固定
        stripe: true, // 是否为斑马纹 table
        highlightCurrentRow: false, // 是否要高亮当前行
        border: true, // 是否有纵向边框
        lazy: false, // 是否需要懒加载
        fit: true, // 列的宽度是否自撑开
        multiSelect: true, //
        seqNo: true,
        isRefresh: true,
        isShowHide: true, // 是否显示显影按钮
        isSearch: false, // 高级查询按钮
        defaultOrderBy: { column: 'id', direction: 'desc' }
      },
      table: {
        total: 0,
        currentPage: 1,
        pageSize: 20,
        data: [],
        // 标题
        column: [
          // SN号
          {
            minWidth: '30',
            prop: 'sn',
            label: 'SN号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 零件号
          {
            minWidth: '30',
            prop: 'partNo',
            label: '生产零件号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 名称
          {
            minWidth: '120',
            prop: 'partName',
            label: '零件名称',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 规格
          {
            minWidth: '140',
            prop: 'specs',
            label: '规格',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '140',
            prop: 'partModel',
            label: '型号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '140',
            prop: 'stockQuantity',
            label: '生产长度',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '140',
            prop: 'prodName',
            label: '产品名称',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '140',
            prop: 'stockQuantityAfter',
            label: '入库长度',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '140',
            prop: 'date',
            label: '日期',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '140',
            prop: 'examiner',
            label: '默认检验员',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '140',
            prop: 'examinerAfter',
            label: '改后检验员',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '140',
            prop: 'partNoAfter',
            label: '改后零件号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '140',
            prop: 'examinerBefore',
            label: '原检验员',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'select',
            optList: () => {
              return this.getExaminerOptions()
            }
          },
          {
            minWidth: '140',
            prop: 'partNoBefore',
            label: '原零件号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '140',
            prop: 'ifsBatchNo',
            label: 'IFS批次号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 打印次数
          {
            minWidth: '140',
            prop: 'printNum',
            label: '打印次数',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 创建人
          {
            minWidth: '200',
            prop: 'createUser',
            label: '创建人',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 创建时间
          {
            minWidth: '200',
            prop: 'createTime',
            label: '创建时间',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'datetimerange'
          },
          // 更新人
          {
            minWidth: '200',
            prop: 'updateUser',
            label: '更新人',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 更新时间
          {
            minWidth: '200',
            prop: 'updateTime',
            label: '更新时间',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'datetimerange'
          }
        ],
        toolbar: [
          {
            text: '新增',
            type: 'primary',
            fun: this.addOrUpdateHandle
          },
          {
            text: '打印',
            type: 'primary',
            fun: this.printLabelOveride
          }
        ],
        operatorConfig: {
          fixed: 'right',
          label: '操作',
          width: 100,
          minWidth: 100
        }
      },
      examinerOptions: []
    }
  },
  components: {
    TableForm,
    ttable,
    secretFormDialog
  },
  created() {
    this.getExaminerDict()
    if (this.permissions.certificate_feedercertificate_delete) {
      this.table.operator = [
        {
          text: '删除',
          type: 'text',
          size: 'small',
          fun: this.deleteHandle
        }
      ]
    }
  },
  computed: {
    ...mapGetters(['permissions'])
  },
  methods: {
    getExaminerDict() {
      remote('examiner_type').then((response) => {
        if (response.data.code === 0) {
          this.examinerOptions = response.data.data
        } else {
          this.examinerOptions = []
        }
      })
    },
    // 获取数据列表
    getData() {
      this.$refs.certificateTable.getDataList()
    },
    // 新增 / 修改
    addOrUpdateHandle(row) {
      this.addOrUpdateVisible = true
      this.$nextTick(() => {
        this.$refs.addOrUpdate.init(row == null ? null : row.id)
      })
    },
    // 删除
    deleteHandle(row) {
      this.$confirm('是否确认SN号为:' + row.sn, '提示', {
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        closeOnClickModal: false,
        type: 'warning'
      })
        .then(function() {
          return delFeederCertificate(row.id)
        })
        .then((data) => {
          this.$message.success('删除成功')
          this.getData()
        })
    },
    // 检验员
    getExaminerOptions() {
      return this.examinerOptions
    },
    handleSelectionChange(val) {
      this.multipleSelection = val
    },
    goOnListPrint(result) {
      if (result) {
        this.printLabel()
      } else {
        this.$message.error('密码错误')
      }
    },
    printLabelOveride() {
      if (this.multipleSelection.length > 0) {
        let flag = true
        this.multipleSelection.forEach((item) => {
          if (item.printNum >= 1) {
            flag = false
          }
        })
        if (flag) {
          this.printLabel()
        } else {
          // 弹出密码确认框
          this.showSecretForm = true
        }
      } else {
        this.$message.error('请选择需打印的零件')
      }
    },
    printLabel() {
      if (this.multipleSelection.length > 0) {
        const currYearAndMonth = getYearAndMonth()
        this.LODOP = getLodop()
        // 找出所有要打印的SN的list
        const snList = []
        this.multipleSelection.forEach((ele) => {
          snList.push(ele.sn)
        })
        // 查询是否正在盘点
        judgeLabelMark(snList).then((resp) => {
          const respData = resp.data
          const markArr = respData.data
          let data
          let markFlag = true
          for (let i = 0; i < this.multipleSelection.length; i++) {
            data = this.multipleSelection[i]
            markFlag = markArr.includes(data.sn)
            if (markFlag) {
              const printExaminer =
                data.examinerAfter == null ? data.examiner : data.examinerAfter
              const qr = {
                part_no: data.partNoAfter,
                lot_batch_no: data.ifsBatchNo,
                qty_arrived: data.stockQuantityAfter,
                wdr: printExaminer,
                material_code:
                  data.cusMaterialCode == null ? '' : data.cusMaterialCode,
                sn_no: data.sn
              }
              const qrStr = JSON.stringify(qr)
              this.LODOP.SET_LICENSES(
                '南通市鑫阳软件开发有限公司',
                '60F8E5078AE17DEB340C94BC7E83CAFF',
                '',
                ''
              )
              this.LODOP.PRINT_INITA(0, -1, 500, 300, '')
              this.LODOP.SET_PRINT_PAGESIZE(0, 1000, 600, '')
              this.LODOP.SET_PRINT_MODE('PRINT_NOCOLLATE', 1)
              this.LODOP.ADD_PRINT_TEXT(102, 5, 87, 20, '产品名称：')
              this.LODOP.SET_PRINT_STYLEA(0, 'FontSize', 10)
              this.LODOP.SET_PRINT_STYLEA(0, 'Alignment', 2)
              this.LODOP.SET_PRINT_STYLEA(0, 'Bold', 1)
              this.LODOP.ADD_PRINT_TEXT(102, 80, 355, 17, data.prodName)
              this.LODOP.SET_PRINT_STYLEA(0, 'FontSize', 10)
              this.LODOP.SET_PRINT_STYLEA(0, 'Bold', 1)
              this.LODOP.ADD_PRINT_TEXT(118, 5, 87, 20, '规格型号：')
              this.LODOP.SET_PRINT_STYLEA(0, 'FontSize', 10)
              this.LODOP.SET_PRINT_STYLEA(0, 'Alignment', 2)
              this.LODOP.SET_PRINT_STYLEA(0, 'Bold', 1)
              this.LODOP.ADD_PRINT_TEXT(118, 80, 180, 17, data.partModel)
              this.LODOP.SET_PRINT_STYLEA(0, 'FontSize', 10)
              this.LODOP.SET_PRINT_STYLEA(0, 'Bold', 1)
              this.LODOP.ADD_PRINT_BARCODE(9, 270, 115, 160, 'QRCode', qrStr)
              this.LODOP.SET_PRINT_STYLEA(0, 'FontSize', 10)
              this.LODOP.SET_PRINT_STYLEA(0, 'QRCodeVersion', 7)
              this.LODOP.SET_PRINT_STYLEA(0, 'QRCodeErrorLevel', 'L')

              this.LODOP.ADD_PRINT_TEXT(134, 17, 87, 20, '零件号：')
              this.LODOP.SET_PRINT_STYLEA(0, 'FontSize', 10)
              this.LODOP.SET_PRINT_STYLEA(0, 'Bold', 1)
              this.LODOP.ADD_PRINT_TEXT(134, 80, 180, 17, data.partNoAfter)
              this.LODOP.SET_PRINT_STYLEA(0, 'FontSize', 10)
              this.LODOP.SET_PRINT_STYLEA(0, 'Bold', 1)

              this.LODOP.ADD_PRINT_TEXT(150, 17, 53, 20, 'SN号：')
              this.LODOP.SET_PRINT_STYLEA(0, 'Bold', 1)
              this.LODOP.ADD_PRINT_TEXT(150, 50, 180, 20, data.sn)
              this.LODOP.SET_PRINT_STYLEA(0, 'Bold', 1)
              this.LODOP.ADD_PRINT_TEXT(150, 145, 180, 20, data.partFamilyNo)
              this.LODOP.SET_PRINT_STYLEA(0, 'Bold', 1)
              this.LODOP.ADD_PRINT_TEXT(118, 241, 53, 20, '日期：')
              this.LODOP.SET_PRINT_STYLEA(0, 'Bold', 1)
              this.LODOP.ADD_PRINT_TEXT(118, 288, 80, 20, data.date)
              this.LODOP.SET_PRINT_STYLEA(0, 'Bold', 1)
              this.LODOP.ADD_PRINT_TEXT(134, 241, 64, 20, '检验员：')
              this.LODOP.SET_PRINT_STYLEA(0, 'Bold', 1)
              this.LODOP.ADD_PRINT_TEXT(134, 290, 80, 20, printExaminer)
              this.LODOP.SET_PRINT_STYLEA(0, 'FontSize', 12)
              this.LODOP.SET_PRINT_STYLEA(0, 'Bold', 1)
              this.LODOP.ADD_PRINT_TEXT(150, 241, 53, 20, '长度：')
              this.LODOP.SET_PRINT_STYLEA(0, 'FontSize', 10)
              this.LODOP.SET_PRINT_STYLEA(0, 'Bold', 1)
              this.LODOP.ADD_PRINT_TEXT(
                150,
                288,
                80,
                16,
                data.stockQuantityAfter != null && data.stockQuantityAfter != ''
                  ? Number(data.stockQuantityAfter) * 1000 + 'm'
                  : ''
              )
              this.LODOP.SET_PRINT_STYLEA(0, 'FontSize', 12)
              this.LODOP.SET_PRINT_STYLEA(0, 'Bold', 1)
              this.LODOP.ADD_PRINT_BARCODE(167, 20, 368, 29, 'Code39', data.sn)
              this.LODOP.SET_PRINT_STYLEA(0, 'FontSize', 8)
              this.LODOP.SET_PRINT_STYLEA(0, 'ShowBarText', 0)
              this.LODOP.ADD_PRINT_LINE(205, 20, 205, 180, 0, 2)
              this.LODOP.ADD_PRINT_LINE(205, 214, 205, 374, 0, 2)
              this.LODOP.ADD_PRINT_TEXT(198, 180, 34, 15, currYearAndMonth)
              this.LODOP.SET_PRINT_STYLEA(0, 'Alignment', 2)
              this.LODOP.ADD_PRINT_LINE(213, 20, 213, 374, 0, 2)
              this.LODOP.ADD_PRINT_TEXT(28, 133, 100, 20, '产品合格证')
              this.LODOP.SET_PRINT_STYLEA(0, 'FontSize', 13)
              this.LODOP.SET_PRINT_STYLEA(0, 'Bold', 1)
              this.LODOP.ADD_PRINT_TEXT(
                56,
                102,
                177,
                20,
                '中天射频电缆有限公司'
              )
              this.LODOP.SET_PRINT_STYLEA(0, 'FontSize', 11)
              this.LODOP.SET_PRINT_STYLEA(0, 'Bold', 1)
              this.LODOP.ADD_PRINT_IMAGE(
                9,
                0,
                105,
                41,
                '<img src="/img/certificatelogo.png"/>'
              )
              this.LODOP.SET_PRINT_STYLEA(0, 'Stretch', 2)
              if (
                data.stockQuantityAfter != null &&
                data.stockQuantityAfter != '' &&
                Number(data.stockQuantityAfter) * 1000 == 200
              ) {
              } else {
                this.LODOP.ADD_PRINT_RECT(0, 0, 370, 223, 0, 7)
              }
              this.LODOP.PRINT()
              // this.LODOP.PREVIEW()
            } else {
              const printExaminer =
                data.examinerAfter == null ? data.examiner : data.examinerAfter
              const qr = {
                part_no: data.partNoAfter,
                lot_batch_no: data.ifsBatchNo,
                qty_arrived: data.stockQuantityAfter,
                wdr: printExaminer,
                material_code:
                  data.cusMaterialCode == null ? '' : data.cusMaterialCode,
                sn_no: data.sn
              }
              const qrStr = JSON.stringify(qr)

              this.LODOP.SET_LICENSES(
                '南通市鑫阳软件开发有限公司',
                '60F8E5078AE17DEB340C94BC7E83CAFF',
                '',
                ''
              )
              this.LODOP.PRINT_INITA(0, -1, 500, 300, '')
              this.LODOP.SET_PRINT_PAGESIZE(0, 1000, 600, '')
              this.LODOP.SET_PRINT_MODE('PRINT_NOCOLLATE', 1)
              this.LODOP.ADD_PRINT_TEXT(106, 5, 87, 20, '产品名称：')
              this.LODOP.SET_PRINT_STYLEA(0, 'FontSize', 10)
              this.LODOP.SET_PRINT_STYLEA(0, 'Alignment', 2)
              this.LODOP.SET_PRINT_STYLEA(0, 'Bold', 1)
              this.LODOP.ADD_PRINT_TEXT(106, 80, 355, 17, data.prodName)
              this.LODOP.SET_PRINT_STYLEA(0, 'FontSize', 10)
              this.LODOP.SET_PRINT_STYLEA(0, 'Bold', 1)
              this.LODOP.ADD_PRINT_TEXT(126, 5, 87, 20, '规格型号：')
              this.LODOP.SET_PRINT_STYLEA(0, 'FontSize', 10)
              this.LODOP.SET_PRINT_STYLEA(0, 'Alignment', 2)
              this.LODOP.SET_PRINT_STYLEA(0, 'Bold', 1)
              this.LODOP.ADD_PRINT_TEXT(126, 80, 180, 17, data.partModel)
              this.LODOP.SET_PRINT_STYLEA(0, 'FontSize', 10)
              this.LODOP.SET_PRINT_STYLEA(0, 'Bold', 1)
              this.LODOP.ADD_PRINT_BARCODE(9, 270, 115, 160, 'QRCode', qrStr)
              this.LODOP.SET_PRINT_STYLEA(0, 'FontSize', 10)
              this.LODOP.SET_PRINT_STYLEA(0, 'QRCodeVersion', 7)
              this.LODOP.SET_PRINT_STYLEA(0, 'QRCodeErrorLevel', 'L')

              this.LODOP.ADD_PRINT_TEXT(146, 17, 87, 20, '零件号：')
              this.LODOP.SET_PRINT_STYLEA(0, 'FontSize', 10)
              this.LODOP.SET_PRINT_STYLEA(0, 'Bold', 1)
              this.LODOP.ADD_PRINT_TEXT(146, 80, 180, 17, data.partNoAfter)
              this.LODOP.SET_PRINT_STYLEA(0, 'FontSize', 10)
              this.LODOP.SET_PRINT_STYLEA(0, 'Bold', 1)

              this.LODOP.ADD_PRINT_TEXT(166, 17, 53, 20, 'SN号：')
              this.LODOP.SET_PRINT_STYLEA(0, 'Bold', 1)
              this.LODOP.ADD_PRINT_TEXT(166, 50, 180, 20, data.sn)
              this.LODOP.SET_PRINT_STYLEA(0, 'Bold', 1)
              this.LODOP.ADD_PRINT_TEXT(166, 145, 180, 20, data.partFamilyNo)
              this.LODOP.SET_PRINT_STYLEA(0, 'Bold', 1)
              this.LODOP.ADD_PRINT_TEXT(126, 241, 53, 20, '日期：')
              this.LODOP.SET_PRINT_STYLEA(0, 'Bold', 1)
              this.LODOP.ADD_PRINT_TEXT(126, 288, 80, 20, data.date)
              this.LODOP.SET_PRINT_STYLEA(0, 'Bold', 1)
              this.LODOP.ADD_PRINT_TEXT(146, 241, 64, 20, '检验员：')
              this.LODOP.SET_PRINT_STYLEA(0, 'Bold', 1)
              this.LODOP.ADD_PRINT_TEXT(146, 290, 80, 20, printExaminer)
              this.LODOP.SET_PRINT_STYLEA(0, 'FontSize', 12)
              this.LODOP.SET_PRINT_STYLEA(0, 'Bold', 1)
              this.LODOP.ADD_PRINT_TEXT(166, 241, 53, 20, '长度：')
              this.LODOP.SET_PRINT_STYLEA(0, 'FontSize', 10)
              this.LODOP.SET_PRINT_STYLEA(0, 'Bold', 1)
              this.LODOP.ADD_PRINT_TEXT(
                166,
                288,
                80,
                16,
                data.stockQuantityAfter != null && data.stockQuantityAfter != ''
                  ? Number(data.stockQuantityAfter) * 1000 + 'm'
                  : ''
              )
              this.LODOP.SET_PRINT_STYLEA(0, 'FontSize', 12)
              this.LODOP.SET_PRINT_STYLEA(0, 'Bold', 1)
              this.LODOP.ADD_PRINT_BARCODE(187, 20, 368, 29, 'Code39', data.sn)
              this.LODOP.SET_PRINT_STYLEA(0, 'FontSize', 8)
              this.LODOP.SET_PRINT_STYLEA(0, 'ShowBarText', 0)
              this.LODOP.ADD_PRINT_TEXT(28, 133, 100, 20, '产品合格证')
              this.LODOP.SET_PRINT_STYLEA(0, 'FontSize', 13)
              this.LODOP.SET_PRINT_STYLEA(0, 'Bold', 1)
              this.LODOP.ADD_PRINT_TEXT(
                56,
                102,
                177,
                20,
                '中天射频电缆有限公司'
              )
              this.LODOP.SET_PRINT_STYLEA(0, 'FontSize', 11)
              this.LODOP.SET_PRINT_STYLEA(0, 'Bold', 1)
              this.LODOP.ADD_PRINT_IMAGE(
                9,
                0,
                105,
                41,
                '<img src="/img/certificatelogo.png"/>'
              )
              this.LODOP.SET_PRINT_STYLEA(0, 'Stretch', 2)
              if (
                data.stockQuantityAfter != null &&
                data.stockQuantityAfter != '' &&
                Number(data.stockQuantityAfter) * 1000 == 200
              ) {
              } else {
                this.LODOP.ADD_PRINT_RECT(0, 0, 370, 223, 0, 7)
              }
              this.LODOP.PRINT()
              // this.LODOP.PREVIEW()
            }
          }
          // 记录打印次数
          const ids = []
          this.multipleSelection.forEach((item) => {
            ids.push(item.id)
          })
          updatePrintNum({ ids: ids, copies: 1 }).then((repsonse) => {
            this.getData()
          })
        })
      } else {
        this.$message.error('请选择需打印的零件')
      }
    }
  }
}
</script>
